import {Component, ViewChild} from '@angular/core';
import {NavigationLink} from "../../navigation-link-list/navigation-link-list.component";
import * as moment from "moment";
import {LabelType, Options} from "ngx-slider-v2";
import {
  ChartComponent,
  ApexAxisChartSeries,
  ApexChart,
  ApexXAxis,
  ApexTitleSubtitle
} from "ng-apexcharts";

export type ChartOptions = {
  series: ApexAxisChartSeries;
  chart: ApexChart;
  xaxis: ApexXAxis;
  title: ApexTitleSubtitle;
};
@Component({
  selector: 'app-taskgroup-activity',
  templateUrl: './taskgroup-activity.component.html',
  styleUrls: ['./taskgroup-activity.component.css']
})
export class TaskgroupActivityComponent {
  defaultNavigationLinkPath: NavigationLink[] = [
    {
      linkText: 'Dashboard',
      routerLink: ['/']
    },
    {
      linkText: 'Statistics',
      routerLink: []
    },
    {
      linkText: 'Taskgroup Activity',
      routerLink: ['/statistics/taskgroup-activity']
    }
  ];

  minValue: number = 50;
  maxValue: number = 200;
  /*options: Options = {
    floor: 0,
    ceil: 250
  };*/

  dateRange: Date[] = this.createDateRange();
  value: number = this.dateRange[0].getTime();
  options: Options = {
    stepsArray: this.dateRange.map((date: Date) => {
      return { value: date.getTime() };
    }),
    translate: (value: number, label: LabelType): string => {
      return new Date(value).toDateString();
    },
    floor: 0,
    ceil: this.dateRange.length,
  };

  @ViewChild("chart") chart?: ChartComponent;
  public chartOptions: Partial<ChartOptions> = {
    series: [
      {
        name: "My-series",
        data: [10, 41, 35, 51, 49, 62, 69, 91, 148]
      }
    ],
    chart: {
      height: 350,
      type: "bar"
    },
    title: {
      text: "My First Angular Chart"
    },
    xaxis: {
      categories: ["Jan", "Feb",  "Mar",  "Apr",  "May",  "Jun",  "Jul",  "Aug", "Sep"]
    }
  };

  createDateRange(): Date[] {
    const dates: Date[] = [];
    for (let i: number = 1; i <= 31; i++) {

      dates.push(moment().subtract(30-i, 'd').toDate());
    }
    return dates;
  }

}
